@@ -11,16 +11,18 @@
   lambdaSel <- self$args$lambda
   estimates <- estimates %>%
     dplyr::mutate(grid_id = self$inner_grid[.data$step, "grid_id"]) %>%
-    dplyr::select(-.data$step) %>%
+    dplyr::select(-"step") %>%
     dplyr::mutate(term = ifelse(.data$term == "", "(Intercept)", .data$term)) %>%
     dplyr::filter(appr_in(.data$lambda, lambdaSel))
   if ("class" %in% colnames(estimates)) {
+    estimates <- estimates %>%
+      dplyr::mutate(class = self$fit_info$class_names_map[.data$class])
     class_vals <- unique(estimates$class)
     if (length(class_vals) == 2) {
       estimates <- estimates %>%
         dplyr::mutate(estimate = .data$estimate * 2) %>%
         dplyr::filter(.data$class == sort(class_vals)[2]) %>%
-        dplyr::select(-.data$class)
+        dplyr::select(-"class")
     }
   }
   return(estimates)
@@ -203,7 +205,8 @@
   estimates <- dplyr::tibble(
     term = names(raw_estimates),
     estimate = raw_estimates
-  )
+  ) %>%
+    dplyr::mutate(term = self$fit_info$names_map[.data$term])
 
   return(estimates)
 
